@@ -15,8 +15,11 @@
 # ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 
-from hcs_utils.path import list_dir, scan_for_new_files, tempdir, walkfiles, \
-        expand, watch_files, watch_files_callback
+from __future__ import absolute_import
+from __future__ import division
+from __future__ import print_function
+from __future__ import unicode_literals
+from hcs_utils.path import list_dir, scan_for_new_files, tempdir, walkfiles, expand, watch_files, watch_files_callback
 from hcs_utils.unittest import eq_
 from pytest import raises
 import os
@@ -82,14 +85,11 @@ def test_walkfiles():
         os.makedirs(os.path.join(tmpd, 'd3', 'dd3'))
         open(os.path.join(tmpd, 'd3', 'dd3', 'ddf3'), 'w').close()
 
-        expected_result = ['f1', 'f2', 'f2.test', 'd2/dd2/ddf2',
-                'd2/dd2/ddf23', 'd3/dd3/ddf3']
-        eq_(list(walkfiles(tmpd)),
-                [os.path.join(tmpd, fn) for fn in expected_result])
+        expected_result = ['f1', 'f2', 'f2.test', 'd2/dd2/ddf2', 'd2/dd2/ddf23', 'd3/dd3/ddf3']
+        eq_(list(walkfiles(tmpd)), [os.path.join(tmpd, fn) for fn in expected_result])
 
         expected_result = ['f2.test']
-        eq_(list(walkfiles(tmpd, pattern='*.test')),
-                [os.path.join(tmpd, fn) for fn in expected_result])
+        eq_(list(walkfiles(tmpd, pattern='*.test')), [os.path.join(tmpd, fn) for fn in expected_result])
 
 
 def test_walkfiles_errors():
@@ -110,25 +110,23 @@ def test_watch_files():
         fn2 = os.path.join(tmpd, 'test2')
         open(fn1, 'w').close()
         print(fn1)
-        generator = watch_files((fn1, fn2), delay=0.1,
-                trigger_on_first_check=True)
-        (path, reason) = generator.next()
+        generator = watch_files((fn1, fn2), delay=0.1, trigger_on_first_check=True)
+        (path, reason) = next(generator)
         eq_(path, fn1)
         eq_(reason, 'INITIAL')
-        import time
         time.sleep(1)
         with open(fn1, 'w') as f:
             f.write('a')
-        (path, reason) = generator.next()
+        (path, reason) = next(generator)
         eq_(path, fn1)
         eq_(reason, 'MODIFIED')
 
         open(fn2, 'w').close()
-        (path, reason) = generator.next()
+        (path, reason) = next(generator)
         eq_(path, fn2)
         eq_(reason, 'CREATED')
         os.unlink(fn2)
-        (path, reason) = generator.next()
+        (path, reason) = next(generator)
         eq_(path, fn2)
         eq_(reason, 'REMOVED')
         generator.close()
@@ -146,10 +144,8 @@ def test_watch_files_callback():
             cb_res['reason'] = reason
 
         def watcher():
-            cb_path = 'wrong'
             watch_files_callback((fn1,), callback, delay=10,
-                    trigger_on_first_check=True,
-                    propagate_callback_errors=False)
+                                 trigger_on_first_check=True, propagate_callback_errors=False)
         thr = threading.Thread(target=watcher)
         thr.daemon = True
         thr.start()
@@ -172,10 +168,9 @@ def test_watch_files_callback_error1():
 
         def watcher():
             try:
-                watch_files_callback((fn1,), callback, delay=10,
-                        trigger_on_first_check=True,
-                        propagate_callback_errors=True)
-            except Exception, e:
+                watch_files_callback((fn1,), callback, delay=10, trigger_on_first_check=True,
+                                     propagate_callback_errors=True)
+            except Exception as e:
                 cb_res['exc'] = e
         thr = threading.Thread(target=watcher)
         thr.daemon = True
@@ -183,7 +178,7 @@ def test_watch_files_callback_error1():
         time.sleep(0.01)
         eq_(cb_res['path'], fn1)
         eq_(cb_res['reason'], 'INITIAL')
-        eq_(cb_res['exc'].message, 'Testing error handling')
+        eq_(str(cb_res['exc']), 'Testing error handling')
 
 
 def test_watch_files_callback_error2():
@@ -199,9 +194,8 @@ def test_watch_files_callback_error2():
             raise Exception('Testing error handling')
 
         def watcher():
-            watch_files_callback((fn1,), callback, delay=10,
-                    trigger_on_first_check=True,
-                    propagate_callback_errors=False)
+            watch_files_callback((fn1,), callback, delay=10, trigger_on_first_check=True,
+                                 propagate_callback_errors=False)
         thr = threading.Thread(target=watcher)
         thr.daemon = True
         thr.start()
